# PyTorch Lightning Spells

[![CircleCI](https://circleci.com/gh/veritable-tech/pytorch-lightning-spells/tree/main.svg?style=svg)](https://circleci.com/gh/veritable-tech/pytorch-lightning-spells/tree/main) [![Documentation Status](https://readthedocs.org/projects/pytorch-lightning-spells/badge/?version=latest)](https://pytorch-lightning-spells.readthedocs.io/en/latest/?badge=latest)

Some useful plugins for [PyTorch Lightning](https://github.com/PyTorchLightning/pytorch-lightning).

[Documentation](https://pytorch-lightning-spells.readthedocs.io/)

## Installation

### PIP

```bash
pip install pytorch-lightning-spells
```

or the latest code in the main branch:

```bash
pip install https://github.com/veritable-tech/pytorch-lightning-spells/archive/main.zip
```

### UV

```bash
uv add pytorch-lightning-spells
```

or the latest code in the main branch:

```bash
uv add git+https://github.com/veritable-tech/pytorch-lightning-spells.git@main
```
